/* ver.A.04.04(ASTROBOY) */


#include "version.h"


VERSION ap_version = {
	"AP.code",
	"ppm2r64",
	"(C) 2000-2004 Hirohisa Mori And GB-group",
	"ver.A.04.04(ASTROBOY)",
	2004,4,15,
	0,
	"ppm to r64/cr format converter ",
};

